@@ -51,14 +51,14 @@ public:
      * @return a string containing all information needed to set the same state.
      * Could be an XML stream
      */
-    virtual QString getState();
+    virtual QString getState() Q_DECL_OVERRIDE;
 
     /**
      * Set the current state
      * MUST BE OVERWRITTEN
      * @param iState must be interpreted to set the state of the widget
      */
-    virtual void setState(const QString& iState);
+    virtual void setState(const QString& iState) Q_DECL_OVERRIDE;
 
 Q_SIGNALS:
     void refreshNeeded();
