@@ -50,7 +50,7 @@ public:
      * Get the main widget
      * @return a widget
      */
-    virtual QWidget* mainWidget();
+    virtual QWidget* mainWidget() Q_DECL_OVERRIDE;
 
     /**
      * Open a bookmark
