@@ -50,49 +50,49 @@ public:
      * @param iArgument the arguments
      * @return true if the plugin is compatible with the document
      */
-    virtual bool setupActions(SKGDocument* iDocument, const QStringList& iArgument);
+    virtual bool setupActions(SKGDocument* iDocument, const QStringList& iArgument) Q_DECL_OVERRIDE;
 
     /**
      * The page widget of the plugin.
      * @return The page widget of the plugin
      */
-    virtual SKGTabPage* getWidget();
+    virtual SKGTabPage* getWidget() Q_DECL_OVERRIDE;
 
     /**
      * The title of the plugin.
      * @return The title of the plugin
      */
-    virtual QString title() const;
+    virtual QString title() const Q_DECL_OVERRIDE;
 
     /**
      * The icon of the plugin.
      * @return The icon of the plugin
      */
-    virtual QString icon() const;
+    virtual QString icon() const Q_DECL_OVERRIDE;
 
     /**
      * The toolTip of the plugin.
      * @return The toolTip of the plugin
      */
-    virtual QString toolTip() const;
+    virtual QString toolTip() const Q_DECL_OVERRIDE;
 
     /**
      * The tips list of the plugin.
      * @return The tips list of the plugin
      */
-    virtual QStringList tips() const;
+    virtual QStringList tips() const Q_DECL_OVERRIDE;
 
     /**
      * Must be implemented to set the position of the plugin.
      * @return integer value between 0 and 999 (default = 999)
      */
-    virtual int getOrder() const;
+    virtual int getOrder() const Q_DECL_OVERRIDE;
 
     /**
      * Must be implemented to know if a plugin must be display in pages chooser.
      * @return true of false (default = false)
      */
-    virtual bool isInPagesChooser() const;
+    virtual bool isInPagesChooser() const Q_DECL_OVERRIDE;
 
 private Q_SLOTS:
     void refreshMainPage();
