@@ -42,7 +42,7 @@ K_PLUGIN_FACTORY(SKGPropertiesPluginFactory, registerPlugin<SKGPropertiesPlugin>
 
 SKGPropertiesPlugin::SKGPropertiesPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) :
     SKGInterfacePlugin(iParent),
-    m_currentDocument(NULL), m_dockWidget(NULL), m_dockContent(NULL), m_addPropertyAction(NULL), m_addPropertyMenu(NULL)
+    m_currentDocument(NULL), m_dockWidget(NULL), m_dockContent(NULL), m_addPropertyMenu(NULL)
 {
     Q_UNUSED(iWidget);
     SKGTRACEINFUNC(10);
@@ -62,7 +62,6 @@ SKGPropertiesPlugin::~SKGPropertiesPlugin()
     m_dockWidget = NULL;
     m_dockContent = NULL;
     m_addPropertyMenu = NULL;
-    m_addPropertyAction = NULL;
 
     if (m_billsProcess.state() == QProcess::Running) {
         m_billsProcess.kill();
@@ -100,6 +99,7 @@ bool SKGPropertiesPlugin::setupActions(SKGDocument* iDocument, const QStringList
 
     m_dockContent = new SKGPropertiesPluginDockWidget(m_currentDocument);
     if (m_dockContent) {
+        connect(m_dockContent, &SKGPropertiesPluginDockWidget::selectionChanged, SKGMainPanel::getMainPanel(), &SKGMainPanel::refresh);
         m_dockWidget = new QDockWidget(SKGMainPanel::getMainPanel());
         if (m_dockWidget) {
             m_dockWidget->setObjectName(QString::fromUtf8("skg_properties_docwidget"));
@@ -121,12 +121,14 @@ bool SKGPropertiesPlugin::setupActions(SKGDocument* iDocument, const QStringList
     }
 
     // Menu
-    m_addPropertyAction = new KToolBarPopupAction(QIcon::fromTheme(icon()), i18nc("Allows user to add a user defined property on an object", "Add property"), this);
-    m_addPropertyMenu = static_cast<QMenu*>(m_addPropertyAction->menu());
+    QStringList tmp;
+    m_currentDocument->getDistinctValues("sqlite_master", "name", "type='table' AND name NOT LIKE 'doctransaction%'", tmp);
+    KToolBarPopupAction* actAddProperty = new KToolBarPopupAction(QIcon::fromTheme(icon()), i18nc("Allows user to add a user defined property on an object", "Add property"), this);
+    m_addPropertyMenu = static_cast<QMenu*>(actAddProperty->menu());
     connect(m_addPropertyMenu, &QMenu::aboutToShow, this, &SKGPropertiesPlugin::onShowAddPropertyMenu);
-    m_addPropertyAction->setStickyMenu(false);
-    m_addPropertyAction->setDelayed(false);
-    registerGlobalAction("add_property", m_addPropertyAction);
+    actAddProperty->setStickyMenu(false);
+    actAddProperty->setDelayed(false);
+    registerGlobalAction("add_property", actAddProperty, tmp, 1, -1, 450);
     return true;
 }
 
@@ -317,9 +319,6 @@ void SKGPropertiesPlugin::refresh()
     if (m_dockContent) {
         m_dockContent->refresh();
     }
-    if (m_addPropertyAction && SKGMainPanel::getMainPanel()) {
-        m_addPropertyAction->setEnabled(SKGMainPanel::getMainPanel()->getSelectedObjects().count() > 0);
-    }
 }
 
 QDockWidget* SKGPropertiesPlugin::getDockWidget()
