@@ -107,7 +107,6 @@ bool SKGUndoRedoPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     m_dockWidget->setObjectName(QString::fromUtf8("skg_undoredo_docwidget"));
     m_dockWidget->setAllowedAreas(Qt::LeftDockWidgetArea | Qt::RightDockWidgetArea);
     m_dockWidget->setWindowTitle(title());
-    m_dockWidget->setWidget(new SKGUndoRedoPluginDockWidget(m_currentDocument));
 
     // add action to control hide / display of history
     QAction* toggle = m_dockWidget->toggleViewAction();
@@ -127,6 +126,13 @@ void SKGUndoRedoPlugin::refresh()
 {
     SKGTRACEINFUNC(10);
 
+    if (m_dockWidget->widget() == NULL) {
+
+        SKGUndoRedoPluginDockWidget* w = new SKGUndoRedoPluginDockWidget(m_currentDocument);
+        connect(w, &SKGUndoRedoPluginDockWidget::selectionChanged, SKGMainPanel::getMainPanel(), &SKGMainPanel::refresh);
+        m_dockWidget->setWidget(w);
+    }
+
     if (m_currentDocument) {
         bool undoPossible = (m_currentDocument->getNbTransaction(SKGDocument::UNDO) > 0);
         if (m_undoSaveAction) {
