@@ -46,7 +46,7 @@
 K_PLUGIN_FACTORY(SKGBankPluginFactory, registerPlugin<SKGBankPlugin>();)
 
 SKGBankPlugin::SKGBankPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/)
-    : SKGInterfacePlugin(iParent), m_currentBankDocument(NULL), m_reconciliateAction(NULL)
+    : SKGInterfacePlugin(iParent), m_currentBankDocument(NULL)
 {
     Q_UNUSED(iWidget);
     SKGTRACEINFUNC(10);
@@ -56,7 +56,6 @@ SKGBankPlugin::~SKGBankPlugin()
 {
     SKGTRACEINFUNC(10);
     m_currentBankDocument = NULL;
-    m_reconciliateAction = NULL;
 }
 
 bool SKGBankPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
@@ -72,10 +71,10 @@ bool SKGBankPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArg
     setXMLFile("skrooge_bank.rc");
 
     // Menu
-    m_reconciliateAction = new QAction(QIcon::fromTheme("window-duplicate"), i18nc("Verb: Reconciliation is process through which you ensure compliance with your bank's statement", "Reconcile..."), this);
-    connect(m_reconciliateAction, &QAction::triggered, this, &SKGBankPlugin::onReconciliate);
-    actionCollection()->setDefaultShortcut(m_reconciliateAction, Qt::ALT + Qt::Key_R);
-    registerGlobalAction("edit_reconciliate", m_reconciliateAction);
+    QAction* actReconciliate = new QAction(QIcon::fromTheme("window-duplicate"), i18nc("Verb: Reconciliation is process through which you ensure compliance with your bank's statement", "Reconcile..."), this);
+    connect(actReconciliate, &QAction::triggered, this, &SKGBankPlugin::onReconciliate);
+    actionCollection()->setDefaultShortcut(actReconciliate, Qt::ALT + Qt::Key_R);
+    registerGlobalAction("edit_reconciliate", actReconciliate, QStringList() << "account", 1, -1, 320);
     return true;
 }
 
@@ -169,24 +168,6 @@ bool SKGBankPlugin::isInPagesChooser() const
     return true;
 }
 
-void SKGBankPlugin::refresh()
-{
-    SKGTRACEINFUNC(10);
-    if (m_currentBankDocument && SKGMainPanel::getMainPanel()) {
-        SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
-        if (selection.count() > 0) {
-            bool onAccount = (selection.at(0).getRealTable() == "account");
-            if (m_reconciliateAction) {
-                m_reconciliateAction->setEnabled(onAccount);
-            }
-        } else {
-            if (m_reconciliateAction) {
-                m_reconciliateAction->setEnabled(false);
-            }
-        }
-    }
-}
-
 void SKGBankPlugin::onReconciliate()
 {
     if (m_currentBankDocument && SKGMainPanel::getMainPanel()) {
