@@ -45,7 +45,7 @@
 K_PLUGIN_FACTORY(SKGCategoriesPluginFactory, registerPlugin<SKGCategoriesPlugin>();)
 
 SKGCategoriesPlugin::SKGCategoriesPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/)
-    : SKGInterfacePlugin(iParent), m_currentBankDocument(NULL), m_importStdCatAction(NULL)
+    : SKGInterfacePlugin(iParent), m_currentBankDocument(NULL)
 {
     Q_UNUSED(iWidget);
     SKGTRACEINFUNC(10);
@@ -55,7 +55,6 @@ SKGCategoriesPlugin::~SKGCategoriesPlugin()
 {
     SKGTRACEINFUNC(10);
     m_currentBankDocument = NULL;
-    m_importStdCatAction = NULL;
 }
 
 bool SKGCategoriesPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
@@ -80,10 +79,10 @@ bool SKGCategoriesPlugin::setupActions(SKGDocument* iDocument, const QStringList
     KSelectAction* contextMenu = new KSelectAction(SKGServices::fromTheme("document-import", overlaycategories), i18nc("Verb", "Import categories"), this);
     registerGlobalAction("import_categories" , contextMenu);
 
-    m_importStdCatAction = contextMenu->addAction(SKGServices::fromTheme("document-import", overlaycategories), i18nc("Verb", "Import standard categories"));
-    m_importStdCatAction->setCheckable(false);
-    connect(m_importStdCatAction, &QAction::triggered, this, &SKGCategoriesPlugin::importStandardCategories);
-    registerGlobalAction("import_standard_categories", m_importStdCatAction);
+    QAction* actImportStdCat = contextMenu->addAction(SKGServices::fromTheme("document-import", overlaycategories), i18nc("Verb", "Import standard categories"));
+    actImportStdCat->setCheckable(false);
+    connect(actImportStdCat, &QAction::triggered, this, &SKGCategoriesPlugin::importStandardCategories);
+    registerGlobalAction("import_standard_categories", actImportStdCat);
 
     foreach(const QString & dir, QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, "skrooge/categories/" % QLocale::countryToString(QLocale().country()), QStandardPaths::LocateDirectory)) {
         QDirIterator it(dir, QStringList() << QStringLiteral("*.qif"));
@@ -168,11 +167,6 @@ void SKGCategoriesPlugin::refresh()
 {
     SKGTRACEINFUNC(10);
     if (m_currentBankDocument) {
-        bool test = (m_currentBankDocument->getDatabase() != NULL);
-        if (m_importStdCatAction) {
-            m_importStdCatAction->setEnabled(test);
-        }
-
         // Automatic categories creation
         if (m_currentBankDocument->getDatabase() != NULL) {
             QString doc_id = m_currentBankDocument->getUniqueIdentifier();
