@@ -37,7 +37,8 @@
 #include "skgperiodedit.h"
 
 SKGOperationBoardWidget::SKGOperationBoardWidget(SKGDocument* iDocument)
-    : SKGBoardWidget(iDocument, i18nc("Dashboard widget title", "Income & Expenditure"))
+    : SKGBoardWidget(iDocument, i18nc("Dashboard widget title", "Income & Expenditure")),
+      m_periodEdit1(NULL), m_periodEdit2(NULL)
 {
     SKGTRACEINFUNC(10);
 
@@ -108,7 +109,8 @@ SKGOperationBoardWidget::SKGOperationBoardWidget(SKGDocument* iDocument)
         addAction(sep);
     }
 
-    m_periodEdit1 = new SKGPeriodEdit(this);
+    m_periodEdit1 = new SKGPeriodEdit(this, true);
+    m_periodEdit1->setObjectName("m_periodEdit1");
     {
         // Set default
         QDomDocument doc("SKGML");
@@ -119,6 +121,7 @@ SKGOperationBoardWidget::SKGOperationBoardWidget(SKGDocument* iDocument)
 
         // Add widget in menu
         QWidgetAction* periodEditWidget = new QWidgetAction(this);
+        periodEditWidget->setObjectName("m_periodEdit1Action");
         periodEditWidget->setDefaultWidget(m_periodEdit1);
 
         addAction(periodEditWidget);
@@ -130,7 +133,8 @@ SKGOperationBoardWidget::SKGOperationBoardWidget(SKGDocument* iDocument)
         addAction(sep);
     }
 
-    m_periodEdit2 = new SKGPeriodEdit(this);
+    m_periodEdit2 = new SKGPeriodEdit(this, true);
+    m_periodEdit2->setObjectName("m_periodEdit2");
     {
         // Set default
         QDomDocument doc("SKGML");
@@ -141,6 +145,7 @@ SKGOperationBoardWidget::SKGOperationBoardWidget(SKGDocument* iDocument)
 
         // Add widget in menu
         QWidgetAction* periodEditWidget = new QWidgetAction(this);
+        periodEditWidget->setObjectName("m_periodEdit2Action");
         periodEditWidget->setDefaultWidget(m_periodEdit2);
 
         addAction(periodEditWidget);
@@ -169,8 +174,8 @@ QString SKGOperationBoardWidget::getState()
     root.setAttribute("menuTransfert", m_menuTransfert && m_menuTransfert->isChecked() ? "Y" : "N");
     root.setAttribute("menuTracked", m_menuTracked && m_menuTracked->isChecked() ? "Y" : "N");
     root.setAttribute("menuSuboperation", m_menuSuboperation && m_menuSuboperation->isChecked() ? "Y" : "N");
-    root.setAttribute("period1", m_periodEdit1->getState());
-    root.setAttribute("period2", m_periodEdit2->getState());
+    root.setAttribute("period1", m_periodEdit1 ? m_periodEdit1->getState() : "");
+    root.setAttribute("period2", m_periodEdit2 ? m_periodEdit2->getState() : "");
     return doc.toString();
 }
 
