@@ -25,9 +25,7 @@
 #include "ui_skgoperationpluginwidget_pref.h"
 
 class QMenu;
-class QAction;
 class SKGDocumentBank;
-class KToolBarPopupAction;
 
 /**
  * This file is Skrooge plugin for operation management
@@ -175,23 +173,7 @@ private Q_SLOTS:
 private:
     Q_DISABLE_COPY(SKGOperationPlugin)
 
-    QAction* m_duplicateAction;
-    QAction* m_createTemplateAction;
-    QAction* m_switchToPointedAction;
-    QAction* m_openHighLights;
-    QAction* m_openLastModified;
-    QAction* m_openSuboperations;
-    QAction* m_openDuplicate;
-    QAction* m_groupOperation;
-    QAction* m_ungroupOperation;
-    QAction* m_mergeOperationAction;
-    QAction* m_open;
-    QAction* m_cleanAlignDate;
-    QAction* m_cleanAlignComment;
-    QAction* m_cleanRemoveGroupWithOneOperation;
-    KToolBarPopupAction* m_applyTemplateAction;
     QMenu* m_applyTemplateMenu;
-
     SKGDocumentBank* m_currentBankDocument;
 
     Ui::skgoperationplugin_pref ui;
