@@ -153,7 +153,7 @@ private:
 
     bool isTemplateMode();
     void displaySubOperations();
-    void displaySubOperations(const SKGOperationObject& iOperation , bool iKeepId = true);
+    void displaySubOperations(const SKGOperationObject& iOperation , bool iKeepId = true, const QDate& iSubOperationsDate = QDate());
     double getRemainingQuantity();
     void addSubOperationLine(int row, const QDate& date, const QString& category, const QString& tracker, const QString& comment, double quantity, const QString& formula, int id = 0);
     SKGError updateSelection(const SKGObjectBase::SKGListSKGObjectBase& iSelection, bool forceCreation = false);
