@@ -56,7 +56,7 @@ public:
      */
     virtual QWidget* createEditor(QWidget* iParent,
                                   const QStyleOptionViewItem& option ,
-                                  const QModelIndex& index) const;
+                                  const QModelIndex& index) const Q_DECL_OVERRIDE;
 
     /**
      * Set the data to be shown in the delegate. For the quantity column,
@@ -65,7 +65,7 @@ public:
      * @param editor
      * @param index
      */
-    virtual void setEditorData(QWidget* editor, const QModelIndex& index) const;
+    virtual void setEditorData(QWidget* editor, const QModelIndex& index) const Q_DECL_OVERRIDE;
 
     /**
      * Get the data to be shown in the model. For the quantity column,
@@ -76,7 +76,7 @@ public:
      * @param model
      * @param index
      */
-    virtual void setModelData(QWidget* editor, QAbstractItemModel* model, const QModelIndex& index) const;
+    virtual void setModelData(QWidget* editor, QAbstractItemModel* model, const QModelIndex& index) const Q_DECL_OVERRIDE;
 
     /**
      * Add a parameter
