@@ -49,8 +49,7 @@
 K_PLUGIN_FACTORY(SKGReportPluginFactory, registerPlugin<SKGReportPlugin>();)
 
 SKGReportPlugin::SKGReportPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) :
-    SKGInterfacePlugin(iParent),
-    m_openReportAction(NULL), m_currentBankDocument(NULL)
+    SKGInterfacePlugin(iParent), m_currentBankDocument(NULL)
 {
     Q_UNUSED(iWidget);
     SKGTRACEINFUNC(10);
@@ -60,7 +59,6 @@ SKGReportPlugin::~SKGReportPlugin()
 {
     SKGTRACEINFUNC(10);
     m_currentBankDocument = NULL;
-    m_openReportAction = NULL;
 }
 
 bool SKGReportPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
@@ -78,10 +76,12 @@ bool SKGReportPlugin::setupActions(SKGDocument* iDocument, const QStringList& iA
     // Menu
     QStringList overlayopen;
     overlayopen.push_back("quickopen");
-    m_openReportAction = new QAction(SKGServices::fromTheme("view-statistics", overlayopen), i18nc("Verb", "Open report..."), this);
-    connect(m_openReportAction, &QAction::triggered, this, &SKGReportPlugin::onOpenReport);
-    actionCollection()->setDefaultShortcut(m_openReportAction, Qt::META + Qt::Key_R);
-    registerGlobalAction("open_report", m_openReportAction);
+    QAction* actOpenReport = new QAction(SKGServices::fromTheme("view-statistics", overlayopen), i18nc("Verb", "Open report..."), this);
+    connect(actOpenReport, &QAction::triggered, this, &SKGReportPlugin::onOpenReport);
+    actionCollection()->setDefaultShortcut(actOpenReport, Qt::META + Qt::Key_R);
+    registerGlobalAction("open_report", actOpenReport,
+                         QStringList() << "operation" << "suboperation" << "account" << "unit" << "category" << "refund" << "payee" << "rule", 1, -1, 120);
+
 
     // ---------------
     QAction* act = new QAction(SKGServices::fromTheme("security-low", overlayopen), i18nc("Verb", "Open very old operations..."), this);
@@ -95,26 +95,6 @@ bool SKGReportPlugin::setupActions(SKGDocument* iDocument, const QStringList& iA
     return true;
 }
 
-void SKGReportPlugin::refresh()
-{
-    SKGTRACEINFUNC(10);
-    if (SKGMainPanel::getMainPanel()) {
-        SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
-
-        if (selection.count() > 0) {
-            QString table = selection.at(0).getRealTable();
-            bool onOperation = (table == "operation" || table == "suboperation" || table == "account" || table == "unit" || table == "category" || table == "refund" || table == "payee" || table == "rule");
-            if (m_openReportAction) {
-                m_openReportAction->setEnabled(onOperation);
-            }
-        } else {
-            if (m_openReportAction) {
-                m_openReportAction->setEnabled(false);
-            }
-        }
-    }
-}
-
 int SKGReportPlugin::getNbDashboardWidgets()
 {
     return 1;
