@@ -403,7 +403,11 @@ void SKGReportPluginWidget::setState(const QString& iState)
 
     ui.kTableWithGraph->setState(tableAndGraphState);
 
+    // Remove previous other filters
+    ui.kOtherFilters->clear();
+
     if (!title.isEmpty() && !wc.isEmpty()) {
+        // Add new filter
         QListWidgetItem* item = new QListWidgetItem(QIcon::fromTheme(title_icon), title);
         item->setCheckState(Qt::Checked);
         item->setFlags(Qt::ItemIsUserCheckable | Qt::ItemIsEnabled);
