@@ -45,6 +45,13 @@ SKGScheduledPluginWidget::SKGScheduledPluginWidget(SKGDocumentBank* iDocument)
 
     ui.setupUi(this);
 
+    // Define action
+    if (SKGMainPanel::getMainPanel()) {
+        QAction* actJumpToOperation = new QAction(QIcon::fromTheme("quickopen"), ui.kJumpBtn->text(), this);
+        connect(actJumpToOperation, &QAction::triggered, this, &SKGScheduledPluginWidget::onJumpToTheOperation);
+        SKGMainPanel::getMainPanel()->registerGlobalAction("edit_reconciliate", actJumpToOperation, true, QStringList() << "recurrentoperation", 1, -1, 160);
+    }
+
     // Set show widget
     ui.kView->getShowWidget()->addGroupedItem("all", i18n("All"), "", "", "", Qt::META + Qt::Key_A);
     ui.kView->getShowWidget()->addGroupedItem("ongoing", i18n("Ongoing"), "task-ongoing", "t_times='N' OR i_nb_times>0", "", Qt::META + Qt::Key_O);
@@ -56,20 +63,6 @@ SKGScheduledPluginWidget::SKGScheduledPluginWidget(SKGDocumentBank* iDocument)
     connect(ui.kView->getView(), &SKGTreeView::doubleClicked, SKGMainPanel::getMainPanel()->getGlobalAction("open"), &QAction::trigger);
     connect(ui.kView->getView(), &SKGTreeView::selectionChangedDelayed, [ = ] {this->onSelectionChanged();});
 
-    // Add registered global action in contextual menu
-    if (SKGMainPanel::getMainPanel()) {
-        ui.kView->getView()->insertGlobalAction();
-        ui.kView->getView()->insertGlobalAction("open");
-
-        m_jumpAction = new QAction(QIcon::fromTheme("quickopen"), ui.kJumpBtn->text(), this);
-        connect(m_jumpAction, &QAction::triggered, this, &SKGScheduledPluginWidget::onJumpToTheOperation);
-
-        ui.kView->getView()->insertAction(0, m_jumpAction);
-        ui.kView->getView()->insertGlobalAction();
-        ui.kView->getView()->insertGlobalAction("edit_delete");
-        ui.kView->getView()->insertGlobalAction();
-    }
-
     // Add Standard KDE Icons to buttons to Operations
     ui.kModifyBtn->setIcon(QIcon::fromTheme("dialog-ok-apply"));
     ui.kProcessBtn->setIcon(QIcon::fromTheme("system-run"));
@@ -184,7 +177,6 @@ void SKGScheduledPluginWidget::onSelectionChanged()
     ui.kModifyBtn->setEnabled(nb);
     ui.kProcessBtn->setEnabled(nb);
     ui.kJumpBtn->setEnabled(nb > 0);
-    m_jumpAction->setEnabled(nb == 1);
 
     if (nb == 1) {
         SKGRecurrentOperationObject recOp(ui.kView->getView()->getFirstSelectedObject());
