@@ -126,18 +126,6 @@ SKGSearchPluginWidget::SKGSearchPluginWidget(SKGDocument* iDocument)
 
     // Add registered global action in contextual menu
     if (SKGMainPanel::getMainPanel()) {
-        ui.kView->getView()->insertGlobalAction();
-        ui.kView->getView()->insertGlobalAction("open");
-        ui.kView->getView()->insertGlobalAction("open_report");
-        ui.kView->getView()->insertGlobalAction();
-        ui.kView->getView()->insertGlobalAction("edit_delete");
-        ui.kView->getView()->insertGlobalAction();
-        ui.kView->getView()->insertGlobalAction("edit_switch_highlight");
-        ui.kView->getView()->insertGlobalAction();
-        ui.kView->getView()->insertGlobalAction("execute_all");
-        ui.kView->getView()->insertGlobalAction("execute_imported");
-        ui.kView->getView()->insertGlobalAction("execute_not_validated");
-
         QMenu* menu = new QMenu(this);
         menu->setIcon(QIcon::fromTheme("system-run"));
         menu->addAction(SKGMainPanel::getMainPanel()->getGlobalAction("execute_all"));
