@@ -47,8 +47,7 @@
 K_PLUGIN_FACTORY(SKGUnitPluginFactory, registerPlugin<SKGUnitPlugin>();)
 
 SKGUnitPlugin::SKGUnitPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/)
-    : SKGInterfacePlugin(iParent), m_currentBankDocument(NULL),
-      m_splitShareAction(NULL)
+    : SKGInterfacePlugin(iParent), m_currentBankDocument(NULL)
 {
     Q_UNUSED(iWidget);
     SKGTRACEINFUNC(10);
@@ -58,7 +57,6 @@ SKGUnitPlugin::~SKGUnitPlugin()
 {
     SKGTRACEINFUNC(10);
     m_currentBankDocument = NULL;
-    m_splitShareAction = NULL;
 }
 
 bool SKGUnitPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
@@ -74,10 +72,10 @@ bool SKGUnitPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArg
     setXMLFile("skrooge_unit.rc");
 
     // Menu
-    m_splitShareAction = new QAction(QIcon::fromTheme("format-text-strikethrough"), i18nc("Verb", "Split share..."), this);
-    connect(m_splitShareAction, &QAction::triggered, this, &SKGUnitPlugin::onSplitShare);
-    actionCollection()->setDefaultShortcut(m_splitShareAction, Qt::ALT + Qt::Key_Slash);
-    registerGlobalAction("edit_split_stock", m_splitShareAction);
+    QAction* actSplitShare = new QAction(QIcon::fromTheme("format-text-strikethrough"), i18nc("Verb", "Split share..."), this);
+    connect(actSplitShare, &QAction::triggered, this, &SKGUnitPlugin::onSplitShare);
+    actionCollection()->setDefaultShortcut(actSplitShare, Qt::ALT + Qt::Key_Slash);
+    registerGlobalAction("edit_split_stock", actSplitShare, QStringList() << "unit", 1, 1, 310);  // TODO (Stephane MANKOWSKI): must be a share
 
     // -----------
     QAction* act = new QAction(QIcon::fromTheme(icon()), i18nc("Verb", "Delete unused units"), this);
@@ -116,72 +114,59 @@ void SKGUnitPlugin::refresh()
 {
     SKGTRACEINFUNC(10);
     if (SKGMainPanel::getMainPanel() && m_currentBankDocument) {
-        bool test = (m_currentBankDocument->getDatabase() != NULL);
-        if (m_splitShareAction) {
-            SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
-            if (selection.count() == 1 && selection.at(0).getRealTable() == "unit") {
-                SKGUnitObject unit(selection.at(0));
-                m_splitShareAction->setEnabled(unit.getType() == SKGUnitObject::SHARE);
-            } else {
-                m_splitShareAction->setEnabled(false);
-            }
-        }
-
         // Automatic download
-        if (test) {
-            QString doc_id = m_currentBankDocument->getUniqueIdentifier();
-            if (m_docUniqueIdentifier != doc_id) {
-                m_docUniqueIdentifier = doc_id;
-                // Check if current unit is existing
-                bool exist = false;
-                SKGError err = m_currentBankDocument->existObjects("unit", "", exist);
-                IFOK(err) {
-                    if (!exist) {
-                        SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Create default unit"), err);
-                        IFOK(err) {
-                            // Create default unit
-                            SKGUnitObject unit;
-                            err = SKGUnitObject::createCurrencyUnit(m_currentBankDocument, QLocale().currencySymbol(QLocale::CurrencyIsoCode), unit);
+        QString doc_id = m_currentBankDocument->getUniqueIdentifier();
+        if (m_docUniqueIdentifier != doc_id) {
+            m_docUniqueIdentifier = doc_id;
+            // Check if current unit is existing
+            bool exist = false;
+            SKGError err = m_currentBankDocument->existObjects("unit", "", exist);
+            IFOK(err) {
+                if (!exist) {
+                    SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Create default unit"), err);
+                    IFOK(err) {
+                        // Create default unit
+                        SKGUnitObject unit;
+                        err = SKGUnitObject::createCurrencyUnit(m_currentBankDocument, QLocale().currencySymbol(QLocale::CurrencyIsoCode), unit);
 
-                            // The file is considered has not modified
-                            m_currentBankDocument->setFileNotModified();
+                        // The file is considered has not modified
+                        m_currentBankDocument->setFileNotModified();
+                    }
+                } else if (skgunit_settings::download_on_open()) {
+                    // Check frequency
+                    QString lastAutomaticDownload = m_currentBankDocument->getParameter("SKG_LAST_UNIT_AUTOMATIC_DOWNLOAD");
+                    if (lastAutomaticDownload.isEmpty()) {
+                        lastAutomaticDownload = "1970-01-01";
+                    }
+                    QDate lastAutomaticDownloadDate = QDate::fromString(lastAutomaticDownload, "yyyy-MM-dd");
+                    if ((lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 1 && skgunit_settings::download_frequency() == 0) ||
+                        (lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 7 && skgunit_settings::download_frequency() == 1) ||
+                        (lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 30 && skgunit_settings::download_frequency() == 2))
+
+                    {
+                        // Download all units
+                        SKGObjectBase::SKGListSKGObjectBase selection;
+                        err = m_currentBankDocument->getObjects("unit", "", selection);
+                        int nb = selection.count();
+                        SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Automatic download of units"), err, nb);
+                        for (int i = 0; !err && i < nb; ++i) {
+                            SKGUnitObject unit(selection.at(i));
+                            err = SKGUnitPluginWidget::downloadUnitValue(unit, SKGUnitPluginWidget::getDownloadModeFromSettings());
+
+                            // Send message
+                            IFOKDO(err, m_currentBankDocument->sendMessage(i18nc("An information to the user", "The unit '%1' has been downloaded", unit.getDisplayName()), SKGDocument::Hidden));
+
+                            IFOKDO(err, m_currentBankDocument->stepForward(i + 1))
                         }
-                    } else if (skgunit_settings::download_on_open()) {
-                        // Check frequency
-                        QString lastAutomaticDownload = m_currentBankDocument->getParameter("SKG_LAST_UNIT_AUTOMATIC_DOWNLOAD");
-                        if (lastAutomaticDownload.isEmpty()) {
-                            lastAutomaticDownload = "1970-01-01";
-                        }
-                        QDate lastAutomaticDownloadDate = QDate::fromString(lastAutomaticDownload, "yyyy-MM-dd");
-                        if ((lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 1 && skgunit_settings::download_frequency() == 0) ||
-                            (lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 7 && skgunit_settings::download_frequency() == 1) ||
-                            (lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 30 && skgunit_settings::download_frequency() == 2))
 
-                        {
-                            // Download all units
-                            SKGObjectBase::SKGListSKGObjectBase selection;
-                            err = m_currentBankDocument->getObjects("unit", "", selection);
-                            int nb = selection.count();
-                            SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Automatic download of units"), err, nb);
-                            for (int i = 0; !err && i < nb; ++i) {
-                                SKGUnitObject unit(selection.at(i));
-                                err = SKGUnitPluginWidget::downloadUnitValue(unit, SKGUnitPluginWidget::getDownloadModeFromSettings());
-
-                                // Send message
-                                IFOKDO(err, m_currentBankDocument->sendMessage(i18nc("An information to the user", "The unit '%1' has been downloaded", unit.getDisplayName()), SKGDocument::Hidden));
-
-                                IFOKDO(err, m_currentBankDocument->stepForward(i + 1))
-                            }
-
-                            // Memorize the last download date
-                            IFOKDO(err, m_currentBankDocument->setParameter("SKG_LAST_UNIT_AUTOMATIC_DOWNLOAD", QDate::currentDate().toString("yyyy-MM-dd")))
-                        }
+                        // Memorize the last download date
+                        IFOKDO(err, m_currentBankDocument->setParameter("SKG_LAST_UNIT_AUTOMATIC_DOWNLOAD", QDate::currentDate().toString("yyyy-MM-dd")))
                     }
                 }
-
-                // Display error
-                SKGMainPanel::displayErrorMessage(err);
             }
+
+            // Display error
+            SKGMainPanel::displayErrorMessage(err);
         }
     }
 }
