@@ -217,18 +217,6 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGDocumentBank* iDocument)
     {
         ui.kUnitTableViewEdition->setModel(new SKGObjectModel(static_cast<SKGDocumentBank*>(getDocument()), "v_unit_display", "", this, "", false));
 
-        // Add registered global action in contextual menu
-        if (SKGMainPanel::getMainPanel()) {
-            ui.kUnitTableViewEdition->getView()->insertGlobalAction();
-            ui.kUnitTableViewEdition->getView()->insertGlobalAction("open");
-            ui.kUnitTableViewEdition->getView()->insertGlobalAction("open_report");
-            ui.kUnitTableViewEdition->getView()->insertGlobalAction();
-            ui.kUnitTableViewEdition->getView()->insertGlobalAction("edit_delete");
-            ui.kUnitTableViewEdition->getView()->insertGlobalAction();
-            ui.kUnitTableViewEdition->getView()->insertGlobalAction("edit_switch_highlight");
-            ui.kUnitTableViewEdition->getView()->insertGlobalAction("edit_split_stock");
-        }
-
         connect(ui.kUnitTableViewEdition->getView(), &SKGTreeView::clickEmptyArea, this, &SKGUnitPluginWidget::cleanEditor);
         connect(ui.kUnitTableViewEdition->getView(), &SKGTreeView::doubleClicked, SKGMainPanel::getMainPanel()->getGlobalAction("open"), &QAction::trigger);
         connect(ui.kUnitTableViewEdition->getView(), &SKGTreeView::selectionChangedDelayed, [ = ] {this->onSelectionChanged();});
@@ -237,12 +225,7 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGDocumentBank* iDocument)
     // Bind unit creation view
     {
         SKGObjectModel* objectModel2 = new SKGObjectModel(static_cast<SKGDocumentBank*>(getDocument()), "v_unitvalue_display", "1=0", this, "", false);
-
         ui.kUnitValueTableViewEdition->setModel(objectModel2);
-
-        // Add registered global action in contextual menu
-        ui.kUnitValueTableViewEdition->insertGlobalAction("edit_delete");
-
         connect(ui.kUnitValueTableViewEdition, &SKGTableView::selectionChangedDelayed, this, &SKGUnitPluginWidget::onSelectionValueChanged);
     }
 
