@@ -75,7 +75,7 @@ public:
     /**
      * Constructor
      * @param iDocument the document containing the object
-     * @param iID the identifier in @p iTable of the object
+     * @param iID the identifier of the object
      */
     explicit SKGRuleObject(SKGDocument* iDocument = NULL, int iID = 0);
 
@@ -272,6 +272,17 @@ public:
      */
     virtual SKGRuleObject::SKGAlarmInfo getAlarmInfo() const;
 
+    /**
+     * Create a rule to update a category on operations having a specific payee
+     * @param iDocument the document containing the object
+     * @param iPayee the payee
+     * @param iCategory the category
+     * @param oRule the created rule
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    static SKGError createPayeeCategoryRule(SKGDocument* iDocument, const QString& iPayee, const QString& iCategory, SKGRuleObject& oRule);
+
     /**
      * Get the list of supported operators
      * @param iAttributeType type of attribute
