@@ -693,7 +693,7 @@ SKGError SKGUnitObject::addSource(const QString& iNewSource, bool iOpenSource)
     QString path = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation);
     QDir(path).mkpath("skrooge/quotes/");
 
-    QString newfile = path + "skrooge/quotes/" % iNewSource % ".txt";
+    QString newfile = path + "/skrooge/quotes/" % iNewSource % ".txt";
 
     // Create the new file
     QSaveFile file(newfile);
