@@ -26,7 +26,7 @@
 #include "skgbasegui_export.h"
 
 class QLabel;
-class QAction;
+class SKGSimplePeriodEdit;
 
 /**
  * This file is a generic Skrooge plugin for html reports
@@ -34,17 +34,28 @@ class QAction;
 class SKGBASEGUI_EXPORT SKGHtmlBoardWidget : public SKGBoardWidget
 {
     Q_OBJECT
-
+    /**
+     * This enumerate for additional options in menu
+     */
+    Q_ENUMS(AdditionalOption)
 public:
+    /**
+     * This enumerate for additional options in menu
+     */
+    enum AdditionalOption {NONE,   /**< No additional option */
+                           PERIOD_ONLY_MONTHS, /**< Add period selector with only months*/
+                           PERIOD_ALL /**< Add period selector with months, quarters, semesters and years*/
+                          };
+
     /**
      * Default Constructor
      * @param iDocument the document
      * @param iTitle the title
      * @param iTemplate the html template
      * @param iTablesRefreshing the list of table refreshing the report when the table is updated. (empty means all)
-     * @param iEnablePreviousMenu to enable the previous menu
+     * @param iOptions to enable options in menu
      */
-    explicit SKGHtmlBoardWidget(SKGDocument* iDocument, const QString& iTitle, const QString& iTemplate, const QStringList& iTablesRefreshing = QStringList(), bool iEnablePreviousMenu = false);
+    explicit SKGHtmlBoardWidget(SKGDocument* iDocument, const QString& iTitle, const QString& iTemplate, const QStringList& iTablesRefreshing = QStringList(), AdditionalOption iOptions = SKGHtmlBoardWidget::NONE);
 
     /**
      * Default Destructor
@@ -79,7 +90,7 @@ private:
     QStringList m_TablesRefreshing;
     bool m_refreshNeeded;
 
-    QAction* m_previousMonth;
+    SKGSimplePeriodEdit* m_period;
 };
 
 #endif  // SKGHTMLBOARDWIDGET_H
