@@ -92,6 +92,13 @@ struct historyPage {
     QList<SKGTabPage::SKGPageHistoryItem> previous;
 };
 
+struct actionDetails {
+    QPointer<QAction> action;
+    QStringList tables;
+    int min;
+    int max;
+    int ranking;
+};
 class SKGMainPanelPrivate
 {
 public:
@@ -104,7 +111,7 @@ public:
     SKGDocument* m_currentDocument;
 
     QList<SKGInterfacePlugin*> m_pluginsList;
-    QMap<QString, QPointer<QAction> > m_registeredGlogalAction;
+    QMap<QString, actionDetails > m_registeredGlogalAction;
     QList<QWidget*> m_hiddenWidgets;
     QList<historyPage> m_historyClosedPages;
 
@@ -112,10 +119,8 @@ public:
     QAction* m_actHideContextItem;
     QAction* m_actShowAllContextItems;
     QAction* m_actDelete;
-    QAction* m_addTabAction;
     QAction* m_tipOfDayAction;
     QAction* m_closePageAction;
-    QAction* m_closeAllPagesAction;
     QAction* m_closeAllOtherPagesAction;
     QAction* m_switchPinState;
     QAction* m_saveDefaultStateAction;
@@ -146,6 +151,7 @@ public:
     bool m_middleClick;
     bool m_saveOnClose;
     QString m_fileName;
+    SKGWidget* m_widgetHavingSelection;
 
 #ifdef KActivities_FOUND
     KActivities::ResourceInstance* m_activityResourceInstance;
@@ -250,13 +256,14 @@ SKGMainPanel::SKGMainPanel(QSplashScreen* iSplashScreen, SKGDocument* iDocument,
     d->m_tabWidget = new SKGTabWidget(this);
     d->m_splashScreen = iSplashScreen;
     d->m_currentDocument = iDocument;
-    d->m_actHideContextItem = NULL; d->m_actShowAllContextItems = NULL; d->m_actDelete = NULL; d->m_addTabAction = NULL; d->m_tipOfDayAction = NULL;
-    d->m_closePageAction = NULL; d->m_closeAllPagesAction = NULL; d->m_closeAllOtherPagesAction = NULL; d->m_switchPinState = NULL; d->m_saveDefaultStateAction = NULL;
+    d->m_actHideContextItem = NULL; d->m_actShowAllContextItems = NULL; d->m_actDelete = NULL; d->m_tipOfDayAction = NULL;
+    d->m_closePageAction = NULL; d->m_closeAllOtherPagesAction = NULL; d->m_switchPinState = NULL; d->m_saveDefaultStateAction = NULL;
     d->m_resetDefaultStateAction = NULL; d->m_overwriteBookmarkStateAction = NULL; d->m_configureAction = NULL; d->m_enableEditorAction = NULL; d->m_fullScreenAction = NULL; d->m_actLock = NULL;
     d->m_actUnLock = NULL;
     d->m_kSystemTrayIcon = NULL;
     d->m_kNormalMessage = NULL; d->m_zoomSelector = NULL;  d->m_previousAction = NULL; d->m_nextAction = NULL; d->m_buttonMenuAction = NULL;
     d->m_mainWidget = NULL; d->m_mainLayout = NULL; d->m_middleClick = false; d->m_saveOnClose = false;
+    d->m_widgetHavingSelection = NULL;
 
     setComponentName("skg", KAboutData::applicationData().displayName());
     setObjectName(qApp->applicationDisplayName());
@@ -763,19 +770,28 @@ bool SKGMainPanel::processArguments(const QStringList& iArgument)
     return output;
 }
 
-void SKGMainPanel::registerGlobalAction(const QString& iIdentifier, QAction* iAction, bool iAddInCollection)
+void SKGMainPanel::registerGlobalAction(const QString& iIdentifier, QAction* iAction, bool iAddInCollection,
+                                        const QStringList& iListOfTable, int iMinSelection, int iMaxSelection,
+                                        int iRanking)
 {
     if (iAction == NULL) {
         SKGTRACE << "WARNING: registerGlobalAction(" << iIdentifier << ",NULL)" << endl;
     } else {
         QStringList keys = d->m_registeredGlogalAction.keys();
         foreach(const QString & id, keys) {
-            QPointer<QAction> act = d->m_registeredGlogalAction[id];
-            if (act && iIdentifier != id && !act->shortcut().isEmpty() && act->shortcut() == iAction->shortcut()) {
+            QPointer<QAction> act = d->m_registeredGlogalAction[id].action;
+            if (act && iIdentifier != id && act != iAction && !act->shortcut().isEmpty() && act->shortcut() == iAction->shortcut()) {
                 SKGTRACE << "WARNING: The actions [" << iAction->text() << " (" << iIdentifier << ")] and [" << act->text() << " (" << id << ")] has same shortcut [" << iAction->shortcut().toString() << "]" << endl;
             }
         }
-        d->m_registeredGlogalAction[iIdentifier] = iAction;
+        actionDetails actDetails;
+        actDetails.action = iAction;
+        actDetails.tables = iListOfTable;
+        actDetails.min = iMinSelection;
+        actDetails.max = iMaxSelection;
+        actDetails.ranking = (iRanking == -1 ? 10 * (d->m_registeredGlogalAction.count() + 1) : iRanking);
+        d->m_registeredGlogalAction[iIdentifier] = actDetails;
+
         // This connect has not been migrated on new connect mechanism to avoid crash when leaving the application
         connect(iAction, SIGNAL(destroyed(QObject*)), this, SLOT(unRegisterGlobalAction(QObject*)));
         if (iAddInCollection) {
@@ -795,24 +811,59 @@ void SKGMainPanel::unRegisterGlobalAction(QObject* iAction)
 {
     QAction* act = qobject_cast< QAction* >(iAction);
     if (act) {
-        foreach(const QString & id, d->m_registeredGlogalAction.keys(act)) {
-            d->m_registeredGlogalAction.remove(id);
+        foreach(const QString & id, d->m_registeredGlogalAction.keys()) {
+            if (d->m_registeredGlogalAction[id].action == QPointer<QAction>(act)) {
+                d->m_registeredGlogalAction.remove(id);
+            }
         }
     }
 }
 
-QAction* SKGMainPanel::getGlobalAction(const QString& iIdentifier, bool iWarnIfNotExist)
+QPointer<QAction> SKGMainPanel::getGlobalAction(const QString& iIdentifier, bool iWarnIfNotExist)
 {
-    QAction* act = d->m_registeredGlogalAction[iIdentifier];
+    QAction* act = d->m_registeredGlogalAction[iIdentifier].action;
     if (act == NULL && iWarnIfNotExist) {
         SKGTRACE << "WARNING: getGlobalAction(" << iIdentifier << ")=NULL" << endl;
     }
     return act;
 }
 
+QList< QPointer< QAction > > SKGMainPanel::getActionsForContextualMenu(const QString& iTable)
+{
+    // Filter action
+    QList<actionDetails> tmp;
+    foreach(const auto & actDetails, d->m_registeredGlogalAction) {
+        if ((actDetails.tables.isEmpty() || actDetails.tables.contains(iTable)) && actDetails.ranking > 0 && actDetails.min > 0) {
+            tmp.push_back(actDetails);
+        }
+    }
+
+    // Sort
+    std::sort(tmp.begin(), tmp.end(), [&](const actionDetails & a, const actionDetails & b) {
+        return a.ranking < b.ranking;
+    });
+
+    // Generate output
+    int previousGroup = -1;
+    QList< QPointer< QAction > > output;
+    foreach(const auto & actDetails, tmp) {
+        int currentGroup = (actDetails.ranking) / 100;
+        if (currentGroup != previousGroup) {
+            output.push_back(NULL);
+            previousGroup = currentGroup;
+        }
+        output.push_back(actDetails.action);
+    }
+    return output;
+}
+
 QMap<QString, QPointer<QAction> > SKGMainPanel::getGlobalActions() const
 {
-    return d->m_registeredGlogalAction;
+    QMap<QString, QPointer<QAction> > map;
+    foreach(const QString & id, d->m_registeredGlogalAction.keys()) {
+        map[id] = d->m_registeredGlogalAction[id].action;
+    }
+    return map;
 }
 
 SKGInterfacePlugin* SKGMainPanel::getPluginByIndex(int iIndex)
@@ -852,17 +903,17 @@ void SKGMainPanel::setupActions()
     KStandardAction::preferences(this, SLOT(optionsPreferences()), actionCollection());
 
     // New Tab
-    d->m_addTabAction = new QAction(QIcon::fromTheme("tab-new-background"), i18nc("Noun, user action", "New Tab"), this);
-    actionCollection()->setDefaultShortcut(d->m_addTabAction, Qt::CTRL + Qt::SHIFT + Qt::Key_W);
-    connect(d->m_addTabAction, &QAction::triggered, this, &SKGMainPanel::addTab);
-    registerGlobalAction("new_tab", d->m_addTabAction);
+    QAction* actAddTab = new QAction(QIcon::fromTheme("tab-new-background"), i18nc("Noun, user action", "New Tab"), this);
+    actionCollection()->setDefaultShortcut(actAddTab, Qt::CTRL + Qt::SHIFT + Qt::Key_W);
+    connect(actAddTab, &QAction::triggered, this, &SKGMainPanel::addTab);
+    registerGlobalAction("new_tab", actAddTab, true, QStringList(), -1);
 
     // Add new tab widget
     QToolButton* addTabButton = new QToolButton(this);
-    addTabButton->setIcon(d->m_addTabAction->icon());
+    addTabButton->setIcon(actAddTab->icon());
     addTabButton->setAutoRaise(true);
     addTabButton->raise();
-    addTabButton->setDefaultAction(d->m_addTabAction);
+    addTabButton->setDefaultAction(actAddTab);
     addTabButton->setToolButtonStyle(Qt::ToolButtonIconOnly);
     d->m_tabWidget->setCornerWidget(addTabButton);
 
@@ -883,10 +934,10 @@ void SKGMainPanel::setupActions()
     registerGlobalAction("tab_close", d->m_closePageAction);
 
     //
-    d->m_closeAllPagesAction = new QAction(QIcon::fromTheme("window-close"), i18nc("Noun, user action", "Close All"), this);
-    actionCollection()->setDefaultShortcut(d->m_closeAllPagesAction, Qt::ALT + Qt::Key_W);
-    connect(d->m_closeAllPagesAction, &QAction::triggered, this, &SKGMainPanel::closeAllPages);
-    registerGlobalAction("tab_closeall", d->m_closeAllPagesAction);
+    QAction* actCloseAllPages = new QAction(QIcon::fromTheme("window-close"), i18nc("Noun, user action", "Close All"), this);
+    actionCollection()->setDefaultShortcut(actCloseAllPages, Qt::ALT + Qt::Key_W);
+    connect(actCloseAllPages, &QAction::triggered, this, &SKGMainPanel::closeAllPages);
+    registerGlobalAction("tab_closeall", actCloseAllPages, true, QStringList(), -1);
 
     //
     d->m_closeAllOtherPagesAction = new QAction(QIcon::fromTheme("window-close"), i18nc("Noun, user action", "Close All Other"), this);
@@ -1325,22 +1376,30 @@ bool SKGMainPanel::queryFileClose()
     return output;
 }
 
-SKGObjectBase::SKGListSKGObjectBase SKGMainPanel::getSelectedObjects()
+SKGObjectBase SKGMainPanel::getFirstSelectedObject() const
+{
+    SKGObjectBase selection;
+    SKGWidget* cPage = (d->m_widgetHavingSelection ? d->m_widgetHavingSelection : currentPage());
+    if (cPage) {
+        selection = cPage->getFirstSelectedObject();
+    }
+    return selection;
+}
+
+SKGObjectBase::SKGListSKGObjectBase SKGMainPanel::getSelectedObjects() const
 {
     SKGObjectBase::SKGListSKGObjectBase selection;
-
-    SKGTabPage* cPage = currentPage();
+    SKGWidget* cPage = (d->m_widgetHavingSelection ? d->m_widgetHavingSelection : currentPage());
     if (cPage) {
         selection = cPage->getSelectedObjects();
     }
     return selection;
 }
 
-int SKGMainPanel::getNbSelectedObjects()
+int SKGMainPanel::getNbSelectedObjects() const
 {
     int nb = 0;
-
-    SKGTabPage* cPage = currentPage();
+    SKGWidget* cPage = (d->m_widgetHavingSelection ? d->m_widgetHavingSelection : currentPage());
     if (cPage) {
         nb = cPage->getNbSelectedObjects();
     }
@@ -1545,6 +1604,31 @@ void SKGMainPanel::refresh()
         d->m_mainWidget->setVisible(!atLeastOnePageOpened);
     }
 
+    // Refresh actions
+    d->m_widgetHavingSelection = qobject_cast<SKGWidget*>(sender());
+    SKGObjectBase selection = SKGMainPanel::getMainPanel()->getFirstSelectedObject();
+    int nbSelectedItems = SKGMainPanel::getMainPanel()->getNbSelectedObjects();
+
+    QString selectedTable = (nbSelectedItems > 0 ? selection.getRealTable() : "");
+    foreach(const auto & actDetails, d->m_registeredGlogalAction) {
+        bool enabled = (actDetails.tables.contains(selectedTable) || actDetails.tables.count() == 0) &&
+                       (nbSelectedItems >= actDetails.min) &&
+                       (nbSelectedItems <= actDetails.max || actDetails.max == -1);
+        if (enabled && nbSelectedItems == 0 && (actDetails.min == 0 || actDetails.min == -1)) {
+            // Check if a page is opened
+            SKGTabPage* page = SKGMainPanel::getMainPanel()->currentPage();
+            if (page) {
+                QAbstractItemView* view = qobject_cast<QAbstractItemView*>(page->mainWidget());
+                enabled = (actDetails.min == 0 || view != NULL);
+            } else {
+                enabled = false;
+            }
+        }
+        if (actDetails.action) {
+            actDetails.action->setEnabled(enabled);
+        }
+    }
+
     // Refresh plugins
     int nb = d->m_pluginsList.count();
     for (int i = 0; i < nb; ++i) {
@@ -1558,18 +1642,12 @@ void SKGMainPanel::refresh()
     } else {
         d->m_switchPinState->setText(i18nc("Noun, user action", "Pin this page"));
     }
-    if (d->m_addTabAction) {
-        d->m_addTabAction->setEnabled(atLeastOnePageOpened);
-    }
     if (d->m_closePageAction) {
         d->m_closePageAction->setEnabled(atLeastOnePageOpened && toSave && !toSave->isPin());
     }
     if (d->m_switchPinState) {
         d->m_switchPinState->setEnabled(atLeastOnePageOpened);
     }
-    if (d->m_closeAllPagesAction) {
-        d->m_closeAllPagesAction->setEnabled(atLeastOnePageOpened);
-    }
     if (d->m_closeAllOtherPagesAction) {
         d->m_closeAllOtherPagesAction->setEnabled(d->m_tabWidget->count() > 1);
     }
