@@ -42,68 +42,68 @@ public:
      * To know if the component is a container
      * @return true or false
      */
-    bool isContainer() const;
+    bool isContainer() const Q_DECL_OVERRIDE;
 
     /**
      * To know if the component is initialized
      * @return true or false
      */
-    bool isInitialized() const;
+    bool isInitialized() const Q_DECL_OVERRIDE;
 
     /**
      * To get the icon for this component
      * @return the icon
      */
-    QIcon icon() const;
+    QIcon icon() const Q_DECL_OVERRIDE;
 
     /**
      * To get the icon for this component
      * @return
      */
-    QString domXml() const;
+    QString domXml() const Q_DECL_OVERRIDE;
 
     /**
      * To get the group for this component
      * @return group
      */
-    QString group() const;
+    QString group() const Q_DECL_OVERRIDE;
 
     /**
      * To get the include file for this component
      * @return the include file
      */
-    QString includeFile() const;
+    QString includeFile() const Q_DECL_OVERRIDE;
 
     /**
      * To get the name for this component
      * @return name
      */
-    QString name() const;
+    QString name() const Q_DECL_OVERRIDE;
 
     /**
      * To get the "tool tip" for this component
      * @return the "tool tip"
      */
-    QString toolTip() const;
+    QString toolTip() const Q_DECL_OVERRIDE;
 
     /**
      * To get the "whats this" for this component
      * @return the "whats this"
      */
-    QString whatsThis() const;
+    QString whatsThis() const Q_DECL_OVERRIDE;
 
     /**
      * To get the widget representing the component
      * @param iParent the parent of the widget
      * @return the widget
      */
-    QWidget* createWidget(QWidget* iParent);
+    QWidget* createWidget(QWidget* iParent) Q_DECL_OVERRIDE;
 
     /**
      * Initilialize the component
      * @param core interface
      */
-    void initialize(QDesignerFormEditorInterface* core);
+    void initialize(QDesignerFormEditorInterface* core) Q_DECL_OVERRIDE;
 
 private:
     bool m_initialized;
