@@ -170,12 +170,6 @@ public:
      */
     virtual void setPin(bool iPin);
 
-Q_SIGNALS:
-    /**
-     * This signal must be launched when the selection is modified
-     */
-    void selectionChanged();
-
 public Q_SLOTS:
     /**
      * Closes this widget
