@@ -95,20 +95,12 @@ SKGTreeView::SKGTreeView(QWidget* iParent)
     QAction* actCopy = KStandardAction::copy(this, SLOT(copy()), NULL);
     actCopy->setProperty("isShortcutConfigurable", false);
     actCopy->setShortcutContext(Qt::WidgetShortcut);
-    if (SKGMainPanel::getMainPanel()) {
-        SKGMainPanel::getMainPanel()->registerGlobalAction("edit_copy", actCopy);
-    }
-    insertGlobalAction("edit_copy");
 
     m_actExpandAll = new QAction(QIcon::fromTheme("format-indent-more"), i18nc("Noun, user action", "Expand all"), this);
     m_actExpandAll->setShortcut(Qt::ALT + Qt::Key_Plus);
     m_actExpandAll->setProperty("isShortcutConfigurable", false);
     m_actExpandAll->setShortcutContext(Qt::WidgetShortcut);
     connect(m_actExpandAll, &QAction::triggered, this, &SKGTreeView::expandAll);
-    if (SKGMainPanel::getMainPanel()) {
-        SKGMainPanel::getMainPanel()->registerGlobalAction("edit_expandall", m_actExpandAll);
-    }
-    insertGlobalAction("edit_expandall");
 
     m_actCollapseAll = new QAction(QIcon::fromTheme("format-indent-less"), i18nc("Noun, user action", "Collapse all"), this);
     m_actCollapseAll->setShortcut(Qt::ALT + Qt::Key_Minus);
@@ -116,10 +108,12 @@ SKGTreeView::SKGTreeView(QWidget* iParent)
     m_actCollapseAll->setShortcutContext(Qt::WidgetShortcut);
     connect(m_actCollapseAll, &QAction::triggered, this, &SKGTreeView::collapseAll);
     if (SKGMainPanel::getMainPanel()) {
+        SKGMainPanel::getMainPanel()->registerGlobalAction("edit_copy", actCopy);
+        SKGMainPanel::getMainPanel()->registerGlobalAction("edit_expandall", m_actExpandAll);
         SKGMainPanel::getMainPanel()->registerGlobalAction("edit_collapseal", m_actCollapseAll);
     }
-    insertGlobalAction("edit_collapseal");
 
+    // Scroll bars
     connect(horizontalScrollBar(), &QScrollBar::actionTriggered, this, &SKGTreeView::onActionTriggered);
     connect(verticalScrollBar(), &QScrollBar::actionTriggered, this, &SKGTreeView::onActionTriggered);
     connect(horizontalScrollBar(), &QScrollBar::rangeChanged, this, &SKGTreeView::onRangeChanged);
@@ -1278,6 +1272,7 @@ void SKGTreeView::setModel(QAbstractItemModel* iModel)
         }
         QTreeView::setModel(iModel);
 
+        rebuildContextualMenu();
         refreshExpandCollapse();
     }
 }
@@ -1287,4 +1282,27 @@ QMenu* SKGTreeView::getHeaderMenu() const
     return m_headerMenu;
 }
 
+void SKGTreeView::rebuildContextualMenu()
+{
+    // Remove all Actions
+    foreach(QAction * act, actions()) {
+        removeAction(act);
+    }
 
+    if (selectionMode() != NoSelection) {
+        // Build contextual menu
+        insertGlobalAction("edit_copy");
+        insertGlobalAction("edit_expandall");
+        insertGlobalAction("edit_collapseal");
+
+        if (m_model) {
+            foreach(QAction * act, SKGMainPanel::getMainPanel()->getActionsForContextualMenu(m_model->getRealTable())) {
+                if (act == NULL) {
+                    insertGlobalAction();
+                } else {
+                    insertAction(0, act);
+                }
+            }
+        }
+    }
+}
