@@ -25,8 +25,8 @@ SKGError::SKGError()
     : QObject(), m_rc(0), m_message(""), m_previousError(NULL)
 {}
 
-SKGError::SKGError(int iRc, const QString& iMessage)
-    : QObject(), m_rc(iRc), m_message(iMessage), m_previousError(NULL)
+SKGError::SKGError(int iRc, const QString& iMessage, const QString& iAction)
+    : QObject(), m_rc(iRc), m_message(iMessage), m_action(iAction), m_previousError(NULL)
 {}
 
 SKGError::SKGError(const SKGError& iError)
@@ -34,6 +34,7 @@ SKGError::SKGError(const SKGError& iError)
 {
     m_rc = iError.m_rc;
     m_message = iError.m_message;
+    m_action = iError.m_action;
     if (Q_UNLIKELY(iError.m_previousError != NULL)) {
         m_previousError = new SKGError(*iError.m_previousError);
     } else {
@@ -55,6 +56,7 @@ SKGError& SKGError::operator= (const SKGError& iError)
 
         m_rc = iError.m_rc;
         m_message = iError.m_message;
+        m_action = iError.m_action;
         if (Q_UNLIKELY(iError.m_previousError != NULL)) {
             m_previousError = new SKGError(*iError.m_previousError);
         }
@@ -143,11 +145,24 @@ int SKGError::getHistoricalSize() const
     return output;
 }
 
-SKGError& SKGError::addError(int iRc, const QString& iMessage)
+
+SKGError& SKGError::setAction(const QString& iAction)
+{
+    m_action = iAction;
+    return *this;
+}
+
+QString SKGError::getAction() const
+{
+    return m_action;
+}
+
+SKGError& SKGError::addError(int iRc, const QString& iMessage, const QString& iAction)
 {
     SKGError* pe = new SKGError(*this);
     setReturnCode(iRc);
     setMessage(iMessage);
+    setAction(iAction);
     delete m_previousError;
     m_previousError = pe;
     return *this;
