@@ -929,29 +929,29 @@ QDate SKGServices::periodToDate(const QString& iPeriod)
     return output;
 }
 
-QString SKGServices::getPerviousPeriod(const QString& iPeriod)
+QString SKGServices::getNeighboringPeriod(const QString& iPeriod, int iDelta)
 {
     QString output = "1=0";
     if (iPeriod.length() == 4) {
         // 2014
-        QDate date = QDate::fromString(iPeriod, "yyyy").addDays(-1);
+        QDate date = QDate::fromString(iPeriod, "yyyy").addYears(iDelta);
         output = date.toString("yyyy");
     } else if (iPeriod.length() == 7) {
         if (iPeriod[5] == 'S') {
             // 2014-S1
             QDate date2 = QDate::fromString(iPeriod, "yyyy-SM");
             date2 = date2.addMonths(date2.month() * 6 - date2.month());  // convert semester in month
-            date2 = date2.addMonths(-6);
+            date2 = date2.addMonths(6 * iDelta);
             output = date2.toString("yyyy-S") % (date2.month() <= 6 ? '1' : '2');
         } else if (iPeriod[5] == 'Q') {
             // 2014-Q1
             QDate date2 = QDate::fromString(iPeriod, "yyyy-QM");
             date2 = date2.addMonths(date2.month() * 3 - date2.month());  // convert quarter in month
-            date2 = date2.addMonths(-3);
+            date2 = date2.addMonths(3 * iDelta);
             output = date2.toString("yyyy-Q") % (date2.month() <= 3 ? '1' : (date2.month() <= 6 ? '2' : (date2.month() <= 9 ? '3' : '4')));
         } else {
             // 2014-07
-            QDate date2 = QDate::fromString(iPeriod, "yyyy-MM").addDays(-1);
+            QDate date2 = QDate::fromString(iPeriod, "yyyy-MM").addMonths(iDelta);
             output = date2.toString("yyyy-MM");
         }
     }
