@@ -224,8 +224,6 @@ int main(int argc, char** argv)
             SKGBEGINTRANSACTION(document1, "IMPORT_SKROOGE_CSV", err);
             SKGImportExportManager imp1(&document1, QUrl::fromLocalFile(SKGTest::getTestPath("OUT") % "/skgtestimportcsv/bankperfect.csv"));
             SKGTESTERROR("imp1.importFile", imp1.importFile(), true);
-            /*TODO(Stephane MANKOWSKI) SKGTEST("imp1:getCSVMapping", SKGServices::stringsToCsv(imp1.getCSVMapping()),
-                    "\"date\";\"account\";\"number\";\"mode\";\"payee\";\"comment\";\"quantity\";\"unit\";\"amount\";\"sign\";\"category\";\"status\";\"bookmarked\";\"\";\"idtransaction\";\"idgroup\"");*/
         }
 
         SKGImportExportManager exp1(&document1, QUrl::fromLocalFile(SKGTest::getTestPath("OUT") % "/skgtestimportcsv/bankperfect2.csv"));
@@ -279,7 +277,6 @@ int main(int argc, char** argv)
             // Scope of the transaction
             SKGBEGINTRANSACTION(document1, "IMPORT", err);
             SKGImportExportManager imp1(&document1, QUrl::fromLocalFile(SKGTest::getTestPath("IN") % "/skgtestimportcsv/XXXXXXMxxxXXXXXXX.csv"));
-            // TODO(Stephane MANKOWSKI) SKGTEST("CSV.getCSVHeaderIndex", imp1.getCSVHeaderIndex(), 8);
             SKGTESTERROR("CSV.importFile", imp1.importFile(), true);
         }
 
@@ -460,7 +457,7 @@ int main(int argc, char** argv)
         SKGAccountObject account(&document1);
         SKGTESTERROR("ACCOUNT.load", account.setName("credit debit"), true);
         SKGTESTERROR("ACCOUNT.load", account.load(), true);
-        SKGTEST("ACCOUNT:getCurrentAmount", SKGServices::doubleToString(account.getCurrentAmount()), "1000");
+        SKGTEST("ACCOUNT:getCurrentAmount", SKGServices::doubleToString(account.getCurrentAmount()), "1500");
     }
     {
         // BACKSLASHES
