@@ -382,6 +382,20 @@ int main(int argc, char** argv)
         SKGTESTERROR("ACCOUNT.load", account.load(), true);
         SKGTEST("ACCOUNT:getCurrentAmount", SKGServices::doubleToString(account.getCurrentAmount()), "-12.34");
     }
+
+    {
+        // Test import OFX from GNUCASH fr Android
+        SKGDocumentBank document1;
+        SKGTESTERROR("document1.initialize()", document1.initialize(), true);
+
+        SKGError err;
+        {
+            // Scope of the transaction
+            SKGBEGINTRANSACTION(document1, "IMPORT_OFX", err);
+            SKGImportExportManager imp1(&document1, QUrl::fromLocalFile(SKGTest::getTestPath("IN") % "/skgtestimportofx/20150818_133327_gnucash_export.ofx"));
+            SKGTESTERROR("imp1.importFile", imp1.importFile(), true);
+        }
+    }
     // End test
     SKGENDTEST();
 }
